<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="14"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="25"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../about.ui" line="48"/>
        <source>Lightweight file manager</source>
        <translation>Легковесный диспетчер файлов</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="58"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="78"/>
        <source>Authors</source>
        <translation>Авторы</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="87"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation>Программирование:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="100"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="109"/>
        <source>PCManFM-Qt File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCMan File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation type="vanished">Файловый менеджер PCMan

Авторское право (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

Эта программа является свободным программным обеспечением;
вы можете распространять и/или модифицировать ее согласно
условиям стандартной общественной лицензии GNU, опубликованной
Фондом свободного ПО; либо версии 2 лицензии, либо
(по вашему выбору) любой более поздней версии.

Эта программа распространяется в надежде что она будет полезной,
но БЕЗ КАКИХ-ЛИБО ГАРАНТИЙ; даже без подразумеваемых гарантий
КОММЕРЧЕСКОЙ ЦЕННОСТИ или ПРИГОДНОСТИ ДЛЯ КОНКРЕТНОЙ ЦЕЛИ.
Смотрите Стандартную Общественную Лицензию GNU для большего
количества деталей.

Вы должны были получить копию Стандартной Общественной Лицензии GNU
вместе с этой программой; если лицензии не было, напишите в Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Бостон, MA  02110-1301, США.</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../../autorun.ui" line="14"/>
        <source>Removable medium is inserted</source>
        <translation>Вставлен съёмный носитель</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="33"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;Вставлен съёмный носитель&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="40"/>
        <source>Type of medium:</source>
        <translation>Тип носителя:</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="47"/>
        <source>Detecting...</source>
        <translation>Обнаружение...</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="56"/>
        <source>Please select the action you want to perform:</source>
        <translation>Выберите действие, которое хотите совершить:</translation>
    </message>
</context>
<context>
    <name>ConnectServerDialog</name>
    <message>
        <location filename="../../connect.ui" line="14"/>
        <source>Connect to remote server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="23"/>
        <source>Anonymous &amp;login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="36"/>
        <source>Login as &amp;user:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="65"/>
        <source>Specify remote folder to connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="72"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="79"/>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="86"/>
        <source>Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="96"/>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../../desktop-folder.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="23"/>
        <source>Desktop</source>
        <translation>Рабочий стол</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="29"/>
        <source>Desktop folder:</source>
        <translation>Папка рабочего стола:</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="36"/>
        <source>Image file</source>
        <translation>Файл изображения</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="42"/>
        <source>Folder path</source>
        <translation>Путь к папке</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="49"/>
        <source>&amp;Browse</source>
        <translation>&amp;Обзор</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../../desktop-preferences.ui" line="14"/>
        <source>Desktop Preferences</source>
        <translation>Настройки рабочего стола</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="24"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="30"/>
        <source>Background</source>
        <translation>Фон</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="52"/>
        <source>Wallpaper mode:</source>
        <translation>Режим обоев:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="65"/>
        <source>Wallpaper image file:</source>
        <translation>Файл изображения обоев:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="85"/>
        <source>Select background color:</source>
        <translation>Выбрать цвет фона:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="94"/>
        <source>Image file</source>
        <translation>Файл изображения</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="100"/>
        <source>Image file path</source>
        <translation>Путь к файлу изображения</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="107"/>
        <source>&amp;Browse</source>
        <translation>&amp;Обзор</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="119"/>
        <source>Icons</source>
        <translation>Значки</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="125"/>
        <source>Icon size:</source>
        <translation>Размер значков:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="138"/>
        <source>Label Text</source>
        <translation>Текст ярлыков</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="176"/>
        <source>Select  text color:</source>
        <translation>Выбрать цвет текста:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="189"/>
        <source>Select shadow color:</source>
        <translation>Выбрать цвет тени:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="202"/>
        <source>Select font:</source>
        <translation>Выбрать шрифт:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="225"/>
        <source>Spacing</source>
        <translation>Расстояние</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="231"/>
        <source>Minimum item margins:</source>
        <translation type="unfinished">Минимальные границы элементов:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="238"/>
        <source>3 px by default.</source>
        <translation>По умолчанию - 3 пикселя.</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="241"/>
        <location filename="../../desktop-preferences.ui" line="265"/>
        <source> px</source>
        <translation> пикс.</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="254"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="261"/>
        <source>1 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>По умолчанию - 3 пикселя.
Также резервируется место для 3 строк текста.</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="278"/>
        <source>Lock</source>
        <translation>Связать</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="315"/>
        <source>Slide Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="321"/>
        <source>Enable Slide Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="333"/>
        <source>Wallpaper image folder:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="340"/>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="347"/>
        <source> hour(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="357"/>
        <source>and</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="370"/>
        <source>Intervals less than 5min will be ignored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="373"/>
        <source>Interval:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="380"/>
        <source> minute(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="406"/>
        <source>Wallpaper folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="429"/>
        <source>Randomize the slide show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="459"/>
        <source>Window Manager</source>
        <translation>Оконный менеджер</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="453"/>
        <source>Advanced</source>
        <translation>Расширенные</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="465"/>
        <source>Show menus provided by window managers when desktop is clicked</source>
        <translation>Показывать меню, предоставляемые оконными менеджерами, по клику на рабочий стол</translation>
    </message>
</context>
<context>
    <name>FindFilesDialog</name>
    <message>
        <source>Find Files</source>
        <translation type="vanished">Найти файлы</translation>
    </message>
    <message>
        <source>Name/Location</source>
        <translation type="vanished">Имя/расположение</translation>
    </message>
    <message>
        <source>File name patterns</source>
        <translation type="vanished">Шаблоны имён файлов</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation type="vanished">Шаблон:</translation>
    </message>
    <message>
        <source>Case insensitive</source>
        <translation type="vanished">Нечувствительный к регистру</translation>
    </message>
    <message>
        <source>Use regular expression</source>
        <translation type="vanished">Использовать регулярное выражение</translation>
    </message>
    <message>
        <source>Places to search</source>
        <translation type="vanished">Места поиска</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="vanished">Добавить</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Удалить</translation>
    </message>
    <message>
        <source>Search in sub directories</source>
        <translation type="vanished">Искать в подпапках</translation>
    </message>
    <message>
        <source>Search hidden files</source>
        <translation type="vanished">Искать скрытые файлы</translation>
    </message>
    <message>
        <source>File Type</source>
        <translation type="vanished">Тип файла</translation>
    </message>
    <message>
        <source>Only search for files of following types:</source>
        <translation type="vanished">Искать только следующие типы файлов:</translation>
    </message>
    <message>
        <source>Text files</source>
        <translation type="vanished">Текстовые файлы</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation type="vanished">Файлы изображений</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation type="vanished">Аудиофайлы</translation>
    </message>
    <message>
        <source>Video files</source>
        <translation type="vanished">Видеофайлы</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="vanished">Документы</translation>
    </message>
    <message>
        <source>Content</source>
        <translation type="vanished">Содержимое</translation>
    </message>
    <message>
        <source>File contains</source>
        <translation type="vanished">Файл содержит</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation type="vanished">Свойства</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation type="vanished">Размер файла</translation>
    </message>
    <message>
        <source>Bigger than:</source>
        <translation type="vanished">Больше, чем:</translation>
    </message>
    <message>
        <source>Smaller than:</source>
        <translation type="vanished">Меньше, чем:</translation>
    </message>
    <message>
        <source>Last Modified Time</source>
        <translation type="vanished">Время последнего изменения</translation>
    </message>
    <message>
        <source>Earlier than:</source>
        <translation type="vanished">Раньше, чем:</translation>
    </message>
    <message>
        <source>Later than:</source>
        <translation type="vanished">Позже, чем:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../main-win.ui" line="14"/>
        <source>File Manager</source>
        <translation>Диспетчер файлов</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="719"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="731"/>
        <source>Ctrl+Alt+N</source>
        <translation>Ctrl+Alt+N</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="vanished">Фильтр</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="93"/>
        <source>Filter by string...</source>
        <translation>Фильтровать по строке...</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="90"/>
        <source>Focus with Ctrl+I</source>
        <translation>Фокус по Ctrl+I</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="120"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="124"/>
        <source>C&amp;reate New</source>
        <translation>&amp;Создать</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="142"/>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="148"/>
        <location filename="../../main-win.ui" line="168"/>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="152"/>
        <source>&amp;Sorting</source>
        <translation>&amp;Сортировка</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="178"/>
        <source>&amp;Toolbars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="185"/>
        <source>Path &amp;Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="202"/>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="217"/>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Закладки</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="224"/>
        <source>&amp;Go</source>
        <translation>&amp;Перейти</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="241"/>
        <source>&amp;Tool</source>
        <translation>&amp;Инструмент</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="261"/>
        <source>Main Toolbar</source>
        <translation>Главная панель инструментов</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="290"/>
        <source>Go &amp;Up</source>
        <translation>Перейти вв&amp;ерх</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="293"/>
        <source>Go Up</source>
        <translation>Перейти вверх</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="296"/>
        <source>Alt+Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="305"/>
        <source>&amp;Home</source>
        <translation>&amp;Домой</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="308"/>
        <source>Alt+Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="317"/>
        <source>&amp;Reload</source>
        <translation>&amp;Обновить</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="320"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="329"/>
        <source>Go</source>
        <translation>Перейти</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="338"/>
        <source>Quit</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="347"/>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="356"/>
        <source>&amp;New Window</source>
        <translation>Новое &amp;окно</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="359"/>
        <source>New Window</source>
        <translation>Новое окно</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="362"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="370"/>
        <source>Show &amp;Hidden</source>
        <translation>Показать &amp;скрытые</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="373"/>
        <source>Ctrl+H</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="382"/>
        <source>&amp;Computer</source>
        <translation>&amp;Компьютер</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="391"/>
        <source>&amp;Trash</source>
        <translation>&amp;Корзина</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="396"/>
        <source>&amp;Network</source>
        <translation>&amp;Сеть</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="405"/>
        <source>&amp;Desktop</source>
        <translation>&amp;Рабочий стол</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="414"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>&amp;Добавить в закладки</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="419"/>
        <source>&amp;Applications</source>
        <translation>&amp;Приложения</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="424"/>
        <source>Reload</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="432"/>
        <source>&amp;Icon View</source>
        <translation>Просмотр &amp;значками</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="440"/>
        <source>&amp;Compact View</source>
        <translation>&amp;Компактный просмотр</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="448"/>
        <source>&amp;Detailed List</source>
        <translation>Просмотр &amp;подробным списком</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="456"/>
        <source>&amp;Thumbnail View</source>
        <translation>Просмотр &amp;эскизами</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="465"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Вырезать</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="468"/>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="477"/>
        <source>&amp;Copy</source>
        <translation>&amp;Копировать</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="480"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="489"/>
        <source>&amp;Paste</source>
        <translation>&amp;Вставить</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="492"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="497"/>
        <source>Select &amp;All</source>
        <translation>Выделить &amp;всё</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="500"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="505"/>
        <source>Pr&amp;eferences</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="513"/>
        <source>&amp;Ascending</source>
        <translation>По &amp;возрастанию</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="521"/>
        <source>&amp;Descending</source>
        <translation>По &amp;убыванию</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="529"/>
        <source>&amp;By File Name</source>
        <translation>&amp;По имени файла</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="537"/>
        <source>By &amp;Modification Time</source>
        <translation>По времени &amp;изменения</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="545"/>
        <source>By File &amp;Type</source>
        <translation>По &amp;типу файла</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="553"/>
        <source>By &amp;Owner</source>
        <translation>По &amp;владельцу</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="561"/>
        <source>&amp;Folder First</source>
        <translation>Сначала &amp;папки</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="569"/>
        <source>&amp;Preserve sorting for this folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="668"/>
        <source>&amp;Case Sensitive</source>
        <translation>&amp;Чувствительная к регистру</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="676"/>
        <source>By File &amp;Size</source>
        <translation>По &amp;размеру файла</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="681"/>
        <source>&amp;Close Window</source>
        <translation>&amp;Закрыть окно</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="684"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="716"/>
        <source>&amp;Folder</source>
        <translation>&amp;Папка</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="728"/>
        <source>&amp;Blank File</source>
        <translation>&amp;Пустой файл</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="736"/>
        <source>&amp;Find Files</source>
        <translation>&amp;Найти файлы</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="739"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="747"/>
        <source>&amp;Filter</source>
        <translation>Фильтр</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="750"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="759"/>
        <source>Close &amp;previous tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="768"/>
        <source>Close &amp;next tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="807"/>
        <source>&amp;Preserve Settings for This Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="812"/>
        <source>Connect to &amp;Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="820"/>
        <source>&amp;Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="828"/>
        <source>&amp;Path Buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close &amp;left tabs</source>
        <translation type="vanished">Закрыть вкладки с&amp;лева</translation>
    </message>
    <message>
        <source>Close &amp;right tabs</source>
        <translation type="vanished">Закрыть вкладки с&amp;права</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="773"/>
        <source>Close &amp;other tabs</source>
        <translation>Закрыть &amp;остальные вкладки</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="781"/>
        <source>&amp;Menu bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="784"/>
        <source>Menu bar</source>
        <translation>Панель меню</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="787"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="796"/>
        <location filename="../../main-win.ui" line="799"/>
        <source>Menu</source>
        <translation>Меню</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="578"/>
        <source>New &amp;Tab</source>
        <translation>Новая &amp;вкладка</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="581"/>
        <source>New Tab</source>
        <translation>Новая вкладка</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="584"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="593"/>
        <source>Go &amp;Back</source>
        <translation>Перейти &amp;назад</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="596"/>
        <source>Go Back</source>
        <translation>Перейти назад</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="599"/>
        <source>Alt+Left</source>
        <translation>Alt+Стрелка_влево</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="608"/>
        <source>Go &amp;Forward</source>
        <translation>Перейти &amp;вперёд</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="611"/>
        <source>Go Forward</source>
        <translation>Перейти вперёд</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="614"/>
        <source>Alt+Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="619"/>
        <source>&amp;Invert Selection</source>
        <translation>&amp;Инвертировать выделение</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="628"/>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="631"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="636"/>
        <source>&amp;Rename</source>
        <translation>&amp;Переименовать</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="639"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="644"/>
        <source>C&amp;lose Tab</source>
        <translation>&amp;Закрыть вкладку</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="647"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="652"/>
        <source>File &amp;Properties</source>
        <translation>Свойства &amp;файла</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="655"/>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="660"/>
        <source>&amp;Folder Properties</source>
        <translation>Свойства &amp;папки</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="689"/>
        <source>Edit Bookmarks</source>
        <translation>Изменить закладки</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="694"/>
        <source>Open &amp;Terminal</source>
        <translation>Открыть &amp;терминал</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="697"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="702"/>
        <source>Open as &amp;Root</source>
        <translation>Открыть от имени &amp;суперпользователя</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="707"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>&amp;Изменить закладки</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../../application.cpp" line="170"/>
        <source>Name of configuration profile</source>
        <translation>Имя профиля конфигурации</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="170"/>
        <source>PROFILE</source>
        <translation>ПРОФИЛЬ</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="173"/>
        <source>Run PCManFM as a daemon</source>
        <translation>Запустить PCManFM как демон</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="176"/>
        <source>Quit PCManFM</source>
        <translation>Выйти из PCManFM</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="179"/>
        <source>Launch desktop manager</source>
        <translation>Запустить менеджер рабочего стола</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="182"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>Отключить менеджер рабочего стола, если он запущен</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="185"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation>Открыть диалог настроек рабочего стола на странице с указанным именем</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="185"/>
        <location filename="../../application.cpp" line="200"/>
        <source>NAME</source>
        <translation>ИМЯ</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="194"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation>Выбрать обои рабочего стола из ФАЙЛА изображения</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="194"/>
        <source>FILE</source>
        <translation>ФАЙЛ</translation>
    </message>
    <message>
        <source>Set mode of desktop wallpaper. MODE=(color|stretch|fit|center|tile)</source>
        <translation type="vanished">Выбрать режим обоев рабочего стола. РЕЖИМ=(color|stretch|fit|center|tile)</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="197"/>
        <source>MODE</source>
        <translation>РЕЖИМ</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="200"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation>Открыть диалог настроек на странице с указанным именем</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="188"/>
        <source>Open new window</source>
        <translation>Открыть новое окно</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="191"/>
        <source>Open Find Files utility</source>
        <translation>Открыть утилиту поиска файлов</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="197"/>
        <source>Set mode of desktop wallpaper. MODE=(%1)</source>
        <translation>Задать режим обоев рабочего стола. РЕЖИМ=(%1)</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="203"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[ФАЙЛ1, ФАЙЛ2,...]</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="203"/>
        <source>Files or directories to open</source>
        <translation>Файлы или папки для открытия</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="540"/>
        <location filename="../../application.cpp" line="545"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="545"/>
        <source>Terminal emulator is not set.</source>
        <translation>Эмулятор терминала не указан.</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../../autorundialog.cpp" line="45"/>
        <source>Open in file manager</source>
        <translation>Открыть в диспетчере файлов</translation>
    </message>
    <message>
        <location filename="../../autorundialog.cpp" line="136"/>
        <source>Removable Disk</source>
        <translation>Съёмный диск</translation>
    </message>
</context>
<context>
    <name>PCManFM::ConnectServerDialog</name>
    <message>
        <location filename="../../connectserverdialog.cpp" line="9"/>
        <source>SSH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="10"/>
        <source>FTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="11"/>
        <source>WebDav</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="12"/>
        <source>Secure WebDav</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="13"/>
        <source>HTTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="14"/>
        <source>HTTPS</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="52"/>
        <source>Fill with background color only</source>
        <translation>Заполнить только цветом фона</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="53"/>
        <source>Stretch to fill the entire screen</source>
        <translation>Растянуть по всему экрану</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="54"/>
        <source>Stretch to fit the screen</source>
        <translation>Растянуть по размеру экрана</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="55"/>
        <source>Center on the screen</source>
        <translation>По центру экрана</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="56"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>Плиточное заполнение всего экрана изображением</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="57"/>
        <source>Zoom the image to fill the entire screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="204"/>
        <source>Image Files</source>
        <translation>Файлы изображений</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../../desktopwindow.cpp" line="525"/>
        <source>Stic&amp;k to Current Position</source>
        <translation>&amp;Прикрепить к текущему положению</translation>
    </message>
    <message>
        <location filename="../../desktopwindow.cpp" line="547"/>
        <source>Desktop Preferences</source>
        <translation>Настройки рабочего стола</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="264"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>Стереть текст (Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="343"/>
        <source>Hide menu bar</source>
        <translation>Скрыть панель меню</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="344"/>
        <source>This will hide the menu bar completely, use Ctrl+M to show it again.</source>
        <translation>Полностью скрыть панель меню; нажмите Ctrl+M, чтобы вернуть ее.</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="628"/>
        <source>Version: %1</source>
        <translation>Версия: %1</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1263"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Переместить в корзину</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1263"/>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1332"/>
        <location filename="../../mainwindow.cpp" line="1340"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1340"/>
        <source>Switch user command is not set.</source>
        <translation>Команда переключения пользователя не задана.</translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.cpp" line="195"/>
        <source>Icon View</source>
        <translation>Просмотр значками</translation>
    </message>
    <message>
        <source>Compact Icon View</source>
        <translation type="vanished">Просмотр компактными значками</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="196"/>
        <source>Compact View</source>
        <translation>Компактный просмотр</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="197"/>
        <source>Thumbnail View</source>
        <translation>Просмотр эскизами</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="198"/>
        <source>Detailed List View</source>
        <translation>Просмотр подробным списком</translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../../tabpage.cpp" line="279"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../../tabpage.cpp" line="292"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>Свободное место: %1 (всего: %2)</translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="309"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n объект</numerusform>
            <numerusform>%n объекта</numerusform>
            <numerusform>%n объектов</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="311"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform> (%n скрыт)</numerusform>
            <numerusform> (%n скрыто)</numerusform>
            <numerusform> (%n скрыто)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="485"/>
        <source>%n item(s) selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 item(s) selected</source>
        <translation type="vanished">%1 объекта(ов) выделено</translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../../view.cpp" line="102"/>
        <source>Open in New T&amp;ab</source>
        <translation>Открыть в новой &amp;вкладке</translation>
    </message>
    <message>
        <location filename="../../view.cpp" line="106"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Открыть в новом &amp;окне</translation>
    </message>
    <message>
        <location filename="../../view.cpp" line="114"/>
        <source>Open in Termina&amp;l</source>
        <translation>Открыть в &amp;терминале</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="45"/>
        <source>User Interface</source>
        <translation>Интерфейс пользователя</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="35"/>
        <source>Behavior</source>
        <translation>Поведение</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="50"/>
        <location filename="../../preferences.ui" line="643"/>
        <source>Thumbnail</source>
        <translation>Эскизы</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="55"/>
        <source>Volume</source>
        <translation>Том</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="60"/>
        <source>Advanced</source>
        <translation>Расширенные</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="220"/>
        <source>Icons</source>
        <translation>Значки</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="252"/>
        <source>Size of big icons:</source>
        <translation>Размер больших значков:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="269"/>
        <source>Size of small icons:</source>
        <translation>Размер маленьких значков:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="286"/>
        <source>Size of thumbnails:</source>
        <translation>Размер эскизов:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="300"/>
        <source>Size of side pane icons:</source>
        <translation>Размер значков боковой панели:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="232"/>
        <source>Icon theme:</source>
        <translation>Тема значков:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="456"/>
        <source>Window</source>
        <translation>Окно</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="469"/>
        <source>Always show the tab bar</source>
        <translation>Всегда показывать панель вкладок</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="487"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>Показывать кнопку «Закрыть» на вкладках</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="494"/>
        <source>Remember the size of the last closed window</source>
        <translation>Запоминать размер последнего закрытого окна</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="501"/>
        <source>Default width of new windows:</source>
        <translation>Ширина новых окон по умолчанию:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="515"/>
        <source>Default height of new windows:</source>
        <translation>Высота новых окон по умолчанию:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="81"/>
        <source>Browsing</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="90"/>
        <source>Open files with single click</source>
        <translation>Открывать файлы по одиночному щелчку мыши</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="100"/>
        <source>Delay of auto-selection in single click mode (0 to disable)</source>
        <translation>Задержка автовыделения в режиме одиночного щелчка (0 для отключения)</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="107"/>
        <source>Default view mode:</source>
        <translation>Режим просмотра по умолчанию:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="120"/>
        <source> sec</source>
        <translation> сек</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="159"/>
        <source>File Operations</source>
        <translation>Операции с файлами</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="165"/>
        <source>Confirm before deleting files</source>
        <translation>Подтверждение перед удалением файлов</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="172"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>Перемещать удалённые файлы в «корзину» вместо удаления их с диска.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="676"/>
        <source>Show thumbnails of files</source>
        <translation>Показывать эскизы файлов</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="666"/>
        <source>Only show thumbnails for local files</source>
        <translation>Показывать эскизы только для локальных файлов</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="40"/>
        <source>Display</source>
        <translation>Вид</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="130"/>
        <source>Bookmarks:</source>
        <translation>Закладки:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="138"/>
        <source>Open in current tab</source>
        <translation>Открывать в текущей вкладке</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="143"/>
        <source>Open in new tab</source>
        <translation>Открывать в новой вкладке</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="148"/>
        <source>Open in new window</source>
        <translation>Открывать в новом окне</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="179"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation>Удалять файлы на съёмных носителях вместо создания «корзины»</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="186"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation>Подтверждение перед перемещением файлов в «корзину»</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="193"/>
        <source>Don&apos;t ask options on launch executable file</source>
        <translation>Не предлагать варианты запуска исполняемых файлов</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="249"/>
        <location filename="../../preferences.ui" line="259"/>
        <source>Used by Icon View</source>
        <translation>Используется в режиме значков</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="266"/>
        <location filename="../../preferences.ui" line="276"/>
        <source>Used by Compact View and Detailed List View</source>
        <translation>Используется в компактном режиме и просмотре подробным списком</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="283"/>
        <location filename="../../preferences.ui" line="293"/>
        <source>Used by Thumbnail View</source>
        <translation>Используется в режиме эскизов</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="313"/>
        <source>User interface</source>
        <translation>Интерфейс пользователя</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="326"/>
        <source>Treat backup files as hidden</source>
        <translation>Рассматривать резервные файлы как скрытые</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="336"/>
        <source>Always show full file names</source>
        <translation>Всегда показывать полные имена файлов</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="346"/>
        <source>Show icons of hidden files shadowed</source>
        <translation>Показывать значки скрытых файлов затенёнными</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="369"/>
        <source>Minimum item margins in icon view:</source>
        <translation type="unfinished">Минимальные границы элементов в режиме значков:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="376"/>
        <source>3 px by default.</source>
        <translation>по умолчанию - 3 пикселя</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="379"/>
        <location filename="../../preferences.ui" line="403"/>
        <source> px</source>
        <translation> пикс.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="392"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="399"/>
        <source>3 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>По умолчанию - 3 пикселя.
Также резервируется место для 3 строк текста.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="416"/>
        <source>Lock</source>
        <translation>Связать</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="465"/>
        <source>When unchecked, the tab bar will be shown
only if there are more than one tab.</source>
        <translation>Если не отмечено, то панель вкладок будет отображаться,
только если есть больше одной вкладки.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="476"/>
        <source>If unchecked, the tab bar will be positioned only
above the folder-view and not above the left pane.</source>
        <translation>Если не отмечено, то панель вкладок будет размещаться
только над областью просмотра папок, но не над левой панелью.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="480"/>
        <source>Fullwidth tab bar</source>
        <translation>Панель вкладок во всю ширину</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="532"/>
        <source>Show in places</source>
        <translation>Показвать в «Местах»</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="539"/>
        <source>Home</source>
        <translation>Дом</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="552"/>
        <source>Desktop</source>
        <translation>Рабочий стол</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="565"/>
        <source>Trash can</source>
        <translation>Корзина</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="578"/>
        <source>Computer</source>
        <translation>Компьютер</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="591"/>
        <source>Applications</source>
        <translation>Приложения</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="599"/>
        <source>Devices</source>
        <translation>Устройства</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="607"/>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="649"/>
        <source>Do not generate thumbnails for image files exceeding this size:</source>
        <translation>Не создавать эскизы для файлов изображений больших чем:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="656"/>
        <source> KB</source>
        <translation> КБ</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="673"/>
        <source>Needs ffmpegthumbnailer</source>
        <translation>Необходим ffmpegthumbnailer</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="703"/>
        <source>Auto Mount</source>
        <translation>Автоподключение</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="709"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>Подключать съёмные тома автоматически при запуске программы</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="716"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>Подключать съёмные тома автоматически при их вставлении</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="723"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>Показывать доступные варианты для съёмных устройств при их вставлении</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="733"/>
        <source>When removable medium unmounted:</source>
        <translation>При отключении съёмного устройства:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="739"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation>Закрыть &amp;вкладку, отображающую содержимое съёмного носителя</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="746"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation>Изме&amp;нить папку во вкладке на домашнюю</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="789"/>
        <source>Switch &amp;user command:</source>
        <translation>Команда смены &amp;пользователя:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="813"/>
        <source>Archiver in&amp;tegration:</source>
        <translation>Ин&amp;теграция с архиваторами:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="836"/>
        <source>Templates</source>
        <translation>Шаблоны</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="842"/>
        <source>Show only user defined templates in menu</source>
        <translation>Показывать в меню только шаблоны, определённые пользователем</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="849"/>
        <source>Show only one template for each MIME type</source>
        <translation>Показывать только один шаблон для каждого типа MIME</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="856"/>
        <source>Run default application after creation from template</source>
        <translation>Запускать приложение по умолчанию после создания из шаблона</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="773"/>
        <source>Programs</source>
        <translation>Программы</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="782"/>
        <source>Terminal emulator:</source>
        <translation>Эмулятор терминала:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="802"/>
        <source>Examples: &quot;xterm -e %s&quot; for terminal or &quot;gksu %s&quot; for switching user.
%s = the command line you want to execute with terminal or su.</source>
        <translation>Примеры: &quot;xterm -e %s&quot; для терминала или &quot;gksu %s&quot; для переключения пользователя.
%s = командная строка,которую вы хотите выполнить с терминалом или su.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="319"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation>Использовать десятичные префиксы СИ вместо двоичных префиксов IEC</translation>
    </message>
</context>
</TS>
